<?php

namespace AuthStack\UserDirectory\Provider;


use Illuminate\Support\ServiceProvider;

class UserDirectoryProvider extends ServiceProvider
{
    public function boot()
    {
        $this->loadRoutesFrom(__DIR__ . '/../../routes/account.php');
        $this->loadRoutesFrom(__DIR__ . '/../../routes/attribute.php');
        $this->loadRoutesFrom(__DIR__ . '/../../routes/group.php');
        $this->loadRoutesFrom(__DIR__ . '/../../routes/organization.php');
        $this->loadRoutesFrom(__DIR__ . '/../../routes/policy.php');

        $this->loadMigrationsFrom(__DIR__ .'/../../database/migrations');
    }
}