<?php

/**
 *
 */

Route::get('/organization/v1',                  'Organization@listing');
Route::get('/organization/v1/{id}',             'Organization@read');
Route::post('/organization/v1',                 'Organization@create');
Route::put('/organization/v1/{id}',             'Organization@update');
Route::delete('/organization/v1/{id}',          'Organization@delete');
Route::post('/organization/v1/{id}/suspend',    'Organization@suspend');
