<?php

use Illuminate\Database\Seeder;

class UserStatus extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $statuses = [
            ['id' => 1, 'title' => 'Active', 'description' => 'Active user accounts'],
            ['id' => 2, 'title' => 'Pending activation', 'description' => 'Account is pending approval / confirmation'],
            ['id' => 3, 'title' => 'Resetting password', 'description' => 'Account owner requested password reset'],
            ['id' => 4, 'title' => 'Password expired', 'description' => 'Password expired, account is locked'],
            ['id' => 5, 'title' => 'Deactivated', 'description' => 'Account is deactivated, no authentication can be performed'],
            ['id' => 6, 'title' => 'Suspended', 'description' => 'Account has been suspended manually by system administrator'],
            ['id' => 7, 'title' => 'Locked out', 'description' => 'Account is locked out due to too many failed authentication attempts'],
        ];

        foreach($statuses as $status)
        {
            DB::table('users_statuses')->insert($status);
        }
    }
}
