<?php

namespace AuthStack\UserDirectory\Http\Requests\Account;

use Illuminate\Foundation\Http\FormRequest;

class Auth extends FormRequest
{
    public function authorize(): bool
    {
        return true;
    }

    public function rules(): array
    {
        return [
            'username' => 'required|max:255',
            'password' => 'required|max:255'
        ];
    }

    public function username(): string
    {
        return $this->input('username');
    }

    public function password(): string
    {
        return $this->input('password');
    }
}