<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateAttributesTable extends Migration
{
    public function up()
    {
        Schema::create('attributes', function(Blueprint $table)
        {
            $table->increments('id')->unsigned();
            $table->string('title', 255);
            $table->string('description')->nullable();
            $table->string('syntax')->nullable();
            $table->timestamps();
        });
    }

    public function down()
    {
        Schema::disableForeignKeyConstraints();
        Schema::dropIfExists('attributes');
    }
}